@@ -21,7 +21,7 @@
 #  If you have any trouble: jfunk@funktronics.ca
 #
 import types, re
-from cElementTree import ElementTree, Element, SubElement, tostring
+from xml.etree.cElementTree import ElementTree, Element, SubElement, tostring
 
 # The Python-XMLTV version
 VERSION = "1.0"
